@@ -26,11 +26,14 @@
 
 // Qt
 #include <QtCore/QFileInfo>
+#include <QtCore/QStandardPaths>
+#include <QtCore/QDir>
 
 // KDE
 #include <KShell>
 #include <KBookmarkMenu>
-#include <KStandardDirs>
+#include <KBookmarkOwner>
+#include <KLocalizedString>
 
 // Konsole
 #include "ViewProperties.h"
@@ -38,7 +41,7 @@
 using namespace Konsole;
 
 BookmarkHandler::BookmarkHandler(KActionCollection* collection,
-                                 KMenu* menu,
+                                 QMenu* menu,
                                  bool toplevel,
                                  QObject* parent)
     : QObject(parent),
@@ -49,9 +52,13 @@ BookmarkHandler::BookmarkHandler(KActionCollection* collection,
 {
     setObjectName(QLatin1String("BookmarkHandler"));
 
-    _file = KStandardDirs::locate("data", "konsole/bookmarks.xml");
-    if (_file.isEmpty())
-        _file = KStandardDirs::locateLocal("data", "konsole/bookmarks.xml");
+    _file = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/bookmarks.xml"));
+
+    if (_file.isEmpty()) {
+        _file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/konsole");
+        QDir().mkpath(_file);
+        _file += QStringLiteral("/bookmarks.xml");
+    }
 
     KBookmarkManager* manager = KBookmarkManager::managerForFile(_file, "konsole");
 
@@ -84,17 +91,17 @@ bool BookmarkHandler::enableOption(BookmarkOption option) const
         return KBookmarkOwner::enableOption(option);
 }
 
-QString BookmarkHandler::currentUrl() const
+QUrl BookmarkHandler::currentUrl() const
 {
     return urlForView(_activeView);
 }
 
-QString BookmarkHandler::urlForView(ViewProperties* view) const
+QUrl BookmarkHandler::urlForView(ViewProperties* view) const
 {
     if (view)
-        return view->url().prettyUrl();
+        return QUrl(view->url());
     else
-        return QString();
+        return QUrl();
 }
 
 QString BookmarkHandler::currentTitle() const
@@ -104,7 +111,7 @@ QString BookmarkHandler::currentTitle() const
 
 QString BookmarkHandler::titleForView(ViewProperties* view) const
 {
-    const KUrl& url = view ? view->url() : KUrl();
+    const QUrl& url = view ? view->url() : QUrl();
     if (url.isLocalFile()) {
         QString path = url.path();
 
@@ -112,14 +119,27 @@ QString BookmarkHandler::titleForView(ViewProperties* view) const
         path = QFileInfo(path).baseName();
 
         return path;
-    } else if (url.hasHost()) {
-        if (url.hasUser())
-            return i18nc("@item:inmenu The user's name and host they are connected to via ssh", "%1 on %2", url.user(), url.host());
+    } else if (!url.host().isEmpty()) {
+        if (!url.userName().isEmpty())
+            return i18nc("@item:inmenu The user's name and host they are connected to via ssh", "%1 on %2", url.userName(), url.host());
         else
             return i18nc("@item:inmenu The host the user is connected to via ssh", "%1", url.host());
     }
 
-    return url.prettyUrl();
+    return url.toDisplayString();
+}
+
+QString BookmarkHandler::currentIcon() const
+{
+    return iconForView(_activeView);
+}
+
+QString BookmarkHandler::iconForView(ViewProperties* view) const
+{
+    if (view)
+        return view->icon().name();
+    else
+        return QString();
 }
 
 bool BookmarkHandler::supportsTabs() const
@@ -127,12 +147,12 @@ bool BookmarkHandler::supportsTabs() const
     return true;
 }
 
-QList<QPair<QString, QString> > BookmarkHandler::currentBookmarkList() const
+QList<KBookmarkOwner::FutureBookmark> BookmarkHandler::currentBookmarkList() const
 {
-    QList<QPair<QString, QString> > list;
+    QList<KBookmarkOwner::FutureBookmark> list;
 
     foreach(ViewProperties* view, _views) {
-        list << QPair<QString, QString>(titleForView(view) , urlForView(view));
+        list << KBookmarkOwner::FutureBookmark(titleForView(view) , urlForView(view), iconForView(view));
     }
 
     return list;
@@ -155,4 +175,3 @@ ViewProperties* BookmarkHandler::activeView() const
     return _activeView;
 }
 
-#include "BookmarkHandler.moc"
