@@ -218,7 +218,6 @@ signals:
      * activated.
      */
     void setMenuBarVisibleRequest(bool);
-    void setSaveGeometryOnExitRequest(bool);
     void updateWindowIcon();
 
     /** Requests creation of a new view with the default profile. */
@@ -347,7 +346,6 @@ private:
     static const ColorScheme* colorSchemeForProfile(const Profile::Ptr profile);
 
     void setupActions();
-    void focusActiveView();
 
     // takes a view from a view container owned by a different manager and places it in
     // newContainer owned by this manager
